@@ -1,8 +1,6 @@
 package File::DataClass::IO;
 
 use 5.010001;
-use namespace::clean -except => 'meta';
-use overload '""' => sub { shift->pathname }, fallback => 1;
 
 use Moo;
 use Cwd                        qw( );
@@ -27,6 +25,9 @@ use Unexpected::Functions      qw( PathNotFound Unspecified );
 use Unexpected::Types          qw( ArrayRef Bool CodeRef Int Maybe Object
                                    PositiveInt RegexpRef SimpleStr Str );
 
+use namespace::clean -except => [ 'import', 'meta' ];
+use overload '""' => sub { shift->pathname }, fallback => 1;
+
 our @EXPORT    = qw( io );
 
 my  @ARG_NAMES = qw( name mode perms );
@@ -426,15 +427,6 @@ sub dirname {
    return $_[ 0 ]->name ? File::Basename::dirname( $_[ 0 ]->name ) : undef;
 }
 
-sub empty {
-   my $self = shift; my $name = $self->name; my $empty;
-
-   $self->exists  or  $self->_throw( class => PathNotFound, args => [ $name ] );
-   $self->is_file and return -z $name ? TRUE : FALSE;
-   $empty = $self->next ? FALSE : TRUE; $self->close;
-   return $empty;
-}
-
 sub encoding {
    my ($self, $encoding) = @_;
 
@@ -580,6 +572,17 @@ sub is_dir {
    return $self->type eq 'dir' ? TRUE : FALSE;
 }
 
+sub is_empty {
+   my $self = shift; my $name = $self->name; my $empty;
+
+   $self->exists  or  $self->_throw( class => PathNotFound, args => [ $name ] );
+   $self->is_file and return -z $name ? TRUE : FALSE;
+   $empty = $self->next ? FALSE : TRUE; $self->close;
+   return $empty;
+}
+
+*empty = \&is_empty; # Deprecated
+
 sub is_executable {
    return $_[ 0 ]->name && -x $_[ 0 ]->name ? TRUE : FALSE;
 }
@@ -617,7 +620,7 @@ sub iterator {
       while (@dirs) {
          while (defined (my $path = $dirs[ 0 ]->next)) {
             $deep and $path->is_dir and ($follow or not $path->is_link)
-               and push @dirs, $path;
+               and unshift @dirs, $path;
             (not defined $filter or (map { $filter->() } ($path))[ 0 ])
                and return $path;
          }
@@ -1425,7 +1428,7 @@ Returns the L<File::Basename> C<dirname> of the passed path
 
    $bool = io( 'path_to_file' )->empty;
 
-Returns true if the pathname exists and is zero bytes in size
+Deprecated in favour of L</is_empty>
 
 =head2 encoding
 
@@ -1508,6 +1511,12 @@ Return true if the pathname is absolute
 
 Tests to see if the IO object is a directory
 
+=head2 is_empty
+
+   $bool = io( 'path_to_file' )->is_empty;
+
+Returns true if the pathname exists and is zero bytes in size
+
 =head2 is_executable
 
    $bool = io( 'path_to_file' )->is_executable;
